@@ -6,8 +6,8 @@
 #' the folder names returned by [prism_archive_ls()] or 
 #' [prism_archive_subset()].
 #' 
-#' Note that station metadata does not exist for "tmean" type or for any 
-#' "annual" temporal periods. 
+#' Note that station metadata does not exist for "tmean" type, any 
+#' "annual" temporal periods, nor for daily normals. 
 #' 
 #' See [prism_archive_subset()] for further details
 #' on specifying ranges of dates for different temporal periods.
@@ -48,6 +48,15 @@ pd_get_station_md <- function(pd)
             "Station metadata does not exist for tmean.")
     pd <- pd[!tmean]
   }
+  
+  # remove daily normals
+  pattern <- "^PRISM_.*?_30yr_normal_.*?_\\d{4}_bil$"
+  dn <- stringr::str_detect(pd, pattern)
+  if (any(dn)) {
+    message("Removing daily normals from `pd`.\n",
+            "Station metadata does not exist for daily normals.")
+    pd <- pd[!dn]
+  }
 
   folders_to_get <- file.path(prism_get_dl_dir(), pd)
   folders_to_get <- pd[dir.exists(folders_to_get)]
@@ -101,7 +110,7 @@ read_md_csv <- function(x) {
   v3 <-  "Station,Name,Longitude,Latitude,Elevation(m),Network"
   v4 <- "Station,Name,Longitude,Latitude,Elevation(m),Network,station_id"
   
-  if (!any(var_names == v1, var_names == v2, var_names == v3, var_names == v4)) {
+  if (!any(var_names == v1, var_names == v2, var_names == v3, var_names == v4)){
     stop(
       "Metadata file does not appear to be formatted as expected.\n",
       "  Please check that the .stn.csv file exists and is from prism.\n",
